var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useState } from 'react';
import { SVG } from 'primeobjects-ui-web-basic';
import { COLORS } from 'primeobjects-helper-util';
import { BubbleMenu } from '@tiptap/react';
import { isFunction, map, isArray, isNil } from 'lodash';
import { getSelectedHightlightColor, getSelectedHightlightText } from './html-helper';
export var HtmlEditorFloatHighlightToolbarContent = function (props) {
    var editor = props.editor;
    var _a = useState(false), showInlineEditNoteUI = _a[0], setShowInlineEditNoteUI = _a[1];
    var InlineEditNoteUI = null;
    var colors = isArray(props.colors) && props.colors.length > 0 ? props.colors : [
        COLORS.RED['100'],
        COLORS.ORANGE['100'],
        COLORS.BLUE['100'],
        COLORS.GREEN['100'],
        COLORS.GRAY['100'],
    ];
    var onClickEditNote = function () {
        var text = getSelectedHightlightText(editor);
        if (!isFunction(props.onClickEditNote))
            return;
        InlineEditNoteUI = props.onClickEditNote(editor, text);
        setShowInlineEditNoteUI(true);
        //if result is not null, it is an inline editor, it will use the same block of tool bar
    };
    var onApplyColor = function (color) {
        var currentColor = getSelectedHightlightColor(editor);
        if (currentColor == color) {
            editor.chain().focus().unsetHighlight().run();
        }
        else {
            editor.chain().focus().toggleHighlight({ color: color }).run();
        }
        if (isFunction(props.onHighlight))
            props.onHighlight(editor, color);
    };
    var renderColorPicker = function () {
        if (showInlineEditNoteUI)
            return null;
        var currentColor = getSelectedHightlightColor(editor);
        return map(colors, function (color) {
            console.log({ currentColor: currentColor, color: color });
            var isActive = color == currentColor;
            return React.createElement("div", { className: "menu", key: color },
                React.createElement("div", { onClick: function () { return onApplyColor(color); }, style: { backgroundColor: color, margin: 2, marginTop: 4, marginBottom: 4, padding: 4 }, className: "menu-color ".concat(isActive ? 'active' : '') }, isActive && React.createElement(SVG, { src: "/icons/platform/checkmark.svg", size: 11 })));
        });
    };
    var renderEditNoteButton = function () {
        //if (!isFunction(props.onClickEditNote) || showInlineEditNoteUI) return null;
        return React.createElement("div", { className: "menu flex", style: { marginTop: 2, marginLeft: 2 } },
            React.createElement("div", { onClick: onClickEditNote, className: "menu-color", style: { width: 18, height: 18 } },
                React.createElement(SVG, { src: "/icons/platform/note.svg", size: 18 })));
    };
    var renderEditNoteUI = function () {
        return InlineEditNoteUI;
    };
    return React.createElement("div", { className: "menu w-full" },
        renderColorPicker(),
        renderEditNoteButton(),
        renderEditNoteUI());
};
export var HtmlEditorFloatHighlightToolbar = function (props) {
    return isNil(props.editor) ? React.createElement(React.Fragment, null) : React.createElement(BubbleMenu, { editor: props.editor, className: "menu-wrapper highlight-toolbar" },
        React.createElement(HtmlEditorFloatHighlightToolbarContent, __assign({}, props)));
};
export default HtmlEditorFloatHighlightToolbar;
